package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````$!@``#0```!<P0```````#0`(``)
M`"@`'``;``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````!*X`
M``2N```%`````!````$```"XO0``N,T``+C-``!8`@``G!(```8`````$```
M`@```,2]``#$S0``Q,T```@!```(`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&1$GP``1)\``$2?``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DN+T`
M`+C-``"XS0``2`(``$@"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`DV6"CQ1##Z`%OWY;@I1+:H\;;8P1````3`````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````3````%````!4````50``
M`%L```!<````70```%\```!@`````````&(```!D````90```&8`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"I`@``````
M```````2````5P,`````````````$@```/X!`````````````!(````1````
M```````````@````<`,`````````````$0```-8#`````````````!(```#V
M`@`````````````1````2`,`````````````$@```"4!`````````````!(`
M``#$`@`````````````2````R```````````````$@```)<!````````````
M`!(```"P`@`````````````2````F```````````````$@```"`!````````
M`````!(```!Z`P`````````````2````_0(`````````````$@```!4!````
M`````````!$```!X`@`````````````2````>P$`````````````$@```/<`
M`````````````!$````$`P`````````````2````20$`````````````$@``
M`-8``````````````!(````K`P`````````````B````Q0$`````````````
M$@```$<"`````````````!(```#V`0`````````````2````E`(`````````
M````$@```+(!`````````````!(```"%`@`````````````2````O@$`````
M````````$@```%<!`````````````!(````-`P`````````````2````+0``
M````````````(````%D"`````````````!(```#0`0`````````````1````
M&@,`````````````$@```'@``````````````!(```"B`@`````````````2
M````7@,`````````````$@```.\!`````````````!(```"G````````````
M```2````LP``````````````$@```'`!`````````````!(```!_`@``````
M```````2````9@(`````````````$@```#8!`````````````!(````7`@``
M```````````2````C0(`````````````$@```&H``````````````!(````J
M`0`````````````2````RP(`````````````$@```*<!`````````````!(`
M```$`0`````````````2````4`,`````````````$@```)L"````````````
M`!(```!Q`P`````````````A````B0$`````````````$@```(<`````````
M`````!(````\```````````````@````Z```````````````$@```&<!````
M`````````!(````A`P`````````````2````M@(`````````````$@```%``
M`````````````"````!>`@`````````````2````<@,`````````````$0``
M`.P"`````````````!(````#`@`````````````2````V0(`````````````
M$@```"@"`````````````!(```!O`@`````````````2````Y`(`````````
M````$@```#H#`````````````!(```#?`P``L%X``'L````2``X`K0,``/1?
M````````$@`/``0$````3@``*0T``!(`#@!K`P``T!4``$`"```2``X`LP,`
M`$!'```%````$@`.`&H$``!01P``'0(``!(`#@!D!```S!$````````2``L`
MEP0``#!;``"``P``$@`.`)(#```0T````````!``&0#K`P``<$D``"(````2
M``X`.`(```Q@```$````$0`0`)X#``!4X````````!``&0!B!```T$4``#L`
M```2``X`=P0``"!-``#8````$@`.`(D$``!@3```>0```!(`#@`1!````-``
M```````0`!@`^`,``*!)``#L````$@`.`(L#```0T````````!``&`!$!```
M#-````0````1`!@`HP,``-!?```"````$@`.`#0$``!P7P``70```!(`#@`7
M!```$!@````````2``X`$P0```#0````````(``8`$X$```(8```!````!$`
M$`#$`P``X$P``#0````2``X`'@0``'!&``#)````$@`.`%4$``"02@``R0$`
M`!(`#@``;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N
M<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`
M7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S
M960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L
M;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`
M7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T
M9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D
M9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<W1A
M8VM?8VAK7V9A:6P`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V9P7VAW`'!A<E]I;FET7V5N
M=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)
M0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N,2XS`$=,
M24)#7S(N-``````"``(``P````(``@`"``(``@`"```````"```````$``(`
M```"```````"```````%````!@`'``(````"``(````(`````@````(````"
M``(`!P`````````"``(````#``(```````@```````(``@`"````````````
M```)``@````"``(`"0`#``D``P`"``(`"``!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``@#?`0``
M$````#`````2:6D-```'`*T$```0````$&EI#0```P"W!`````````$`!@`N
M`@``$``````````2:6D-```)`*T$```0````=!EI"0``"`#!!```$````'(9
M:0D```8`S00``!````!S'VD)```%`-D$```0````%&EI#0``!`#E!```$```
M`!!I:0T```(`MP0```````"XS0``"````+S-```(````[,\```@````$T```
M"`````S0```(````R,\```8$``#,SP``!@<``-#/```&#```U,\```82``#8
MSP``!A4``-S/```&&0``X,\```8C``#DSP``!B4``.C/```&,```\,\```8\
M``#TSP``!CT``/C/```&0@``_,\```9$``#8S@``!P$``-S.```'`@``X,X`
M``<#``#DS@``!P8``.C.```'"```[,X```<)``#PS@``!PH``/3.```'"P``
M^,X```<-``#\S@``!PX```#/```'#P``!,\```<0```(SP``!Q$```S/```'
M$P``$,\```<4```4SP``!Q8``!C/```'%P``',\```<8```@SP``!QH``"3/
M```'&P``*,\```<<```LSP``!QT``##/```''@``-,\```<?```XSP``!R``
M`#S/```'(0``0,\```<B``!$SP``!R0``$C/```')@``3,\```<G``!0SP``
M!R@``%3/```'*0``6,\```<J``!<SP``!RL``&#/```'+```9,\```<M``!H
MSP``!RX``&S/```'+P``<,\```<Q``!TSP``!S(``'C/```',P``?,\```<T
M``"`SP``!S4``(3/```'-@``B,\```<W``",SP``!S@``)#/```'.0``E,\`
M``<[``"8SP``!SX``)S/```'/P``H,\```=```"DSP``!T$``*C/```'0P``
MK,\```=%``"PSP``!T8``+3/```'1P``N,\```=(``"\SP``!TD``,#/```'
M2@``Q,\```=+``!3@^P(Z'L&``"!P_>\``"+@Q0!``"%P'0%Z-X#``"#Q`A;
MPP#_LP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(````
MZ=#_____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'````&@@
M````Z:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C*```
M`&@X````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/____^C
M-````&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I(/__
M__^C0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@```#I
M\/[___^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````:)``
M``#IP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@````
M:*@```#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O___Z-L
M````:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`_O__
M_Z-X````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ````.D0
M_O___Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H``$`
M`.G@_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@```!H
M&`$``.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____HZ0`
M``!H,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]____
MH[````!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``Z3#]
M____H[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP`0``
MZ0#]____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT````&B(
M`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^CW```
M`&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S___^C
MZ````&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I4/S_
M__^C]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z,0`0``9I#_HQ0!
M``!FD(U,)`2#Y/#_<?Q5B>575E-1B<[H:`(``('#Y+@``(/L+(M!!(E%U(M!
M"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z+K]__^+@QP!``"#Q`Q04/^S)`$`
M`.@$20``BX,,`0``@\00@#@`#X0F`0``B[L(`0``@^P,_S?H$O___X"(_@(`
M``):_S?H`____X"(_@(```&+!H/$$(/`!3W___\_#X=9`0``@^P,P>`"4.C=
M_/__BWW4BS:#Q!")@W@1``#'@WP1```$````BQ>#_@&)$(V3$Y/__XE0!(N3
M0`$``(E0"(V3%I/__XE0#+H!````?A*-="8`BPR7B4R0#(/"`3G6=?*#[`S'
M1+`,`````(/&`VH`4(V#1'?__U90_[.$$0``Z+;]__^#Q""%P(G&#X26````
M@^P,_[.$$0``C7W@Z,C[__^-@^.1__^)^NC[)P``@\00A<`/A(4```"#[`S_
MLX01``#H8OO__^@]_?__@\00B?"+?>1E,ST4````#X6I````C67P65M>7UV-
M8?S#Z+?[__^%P(F#A!$```^$CP```(/L#%#H$/O__XN["`$``%G_-^C2_?__
M@\00QH!Q!0```.FG_O__@^P,_[.$$0``Z&7]__^#Q!")QNE2____BX.`$0``
MA<!T)8/L#%#HZ$8``(/$$.E@____4%"-@Y.1____LQ@!``!0Z#S\__^-@YB1
M__^)^N@O)P``A<")@X`1```/A#'____KONC:1P``@^P,:@'HH/O__S'M7HGA
M@^3P4%12Z"(```"!PZRV``"-@P21__]0C8.DD/__4%%6_[,@`0``Z*_[___T
MBQPDPV:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z!<!``"!PF>V``"-BD0!
M``"-@D<!```IR(/X!G87BX+\````A<!T#56)Y8/L%%'_T(/$$,GSPXGVC;PG
M`````.C7````@<(GM@``58V*1`$``(V"1`$``(GE4RG(P?@"@^P$B</!ZQ\!
MV-'X=!2+DBP!``"%TG0*@^P(4%'_TH/$$(M=_,G#B?:-O"<`````58GE4^A7
M____@</3M0``@^P$@+M4`0```'4GBX,0`0``A<!T$8/L#/^S.`$``.B=_/__
M@\00Z#7____&@U0!```!BUW\R<.)]HV\)P````#H-P```('"A[4``(V"]/[_
M_XL(A<EU">E$____C70F`(N2*`$``(72=.U5B>6#[!10_]*#Q!#)Z23___^+
M%"3#55>-:#A64X'L#`,``(E$)$R-1"1XB70D$&6+'10```")G"3\`@``,=N)
M1"0(B7PD%(G!D(UT)@"+5)T`BT2=!,=$V00`````QT39#`````#'1"0$````
M``_*B00DB139B<+!Z!C!Z@B!X@#_```)T(L4)(G'BP0DP>(8P>`("=<E``#_
M``GXB439"(/#`H/[$'6EBT0D"(V4)'@"``")%"2)Q9"-="8`BU5HBT5L@\4(
M,U4X,T4\,U4(,T4,,U7X,T7\QT5\`````(G'B=")T0^L^!\!T0G!B4UX.RPD
M=<B+1"1,BW`,BT@<BU@(BSB+:`2+4!B)="0<B4PD#(MP%(M(((E<)!B+6!")
M;"04B50D"#'2B4PD6(ET)`2)^8G^B1PDBU@D#ZSI&\'F!8E\)!")]8MT)%B)
M7"1<"<T#="1XBWPD7!-\)'R)Z(GQ@<&9>8):B?N#TP`!R(M,)!@1VHL<)(E$
M)"")5"0DBU0D"(G?,=<ASXGZBWPD"(MT)""+1"08QT0D)`````#'1"0T````
M`#'Z`=:+5"0<B<>)="0@B70D*,'G'HG&B?F+?"0(#ZS6`HG-BP0DBU0D)`GU
M`[PD@````(EL)#"+;"0,$ZPDA````(GY@<&9>8):B>N+;"0PB4PD.(/3`(M,
M)#B)7"0\QT0D/``````QQ8M$)!")[R''BT0D((G[BSPDB<8Q^XG'BT0D$`'9
MP>8%B70D.(MT)#B)RP^LUQN+5"04B<$)_@'SP>$>,?\/K-`"B<V+5"0PB5PD
M4`G%B6PD.(ML)"#WU2'JBVPD*"-L)#C'1"0L`````,=$)$0`````B>B)U8M4
M)"0)Q8L$)`.$)(@```")Z<=$)"0`````!9EY@EH!P8G8P>`%B40D*(G8BVPD
M*`^L^!N)1"1`"VPD0(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<V+5"0X"<6+
M1"0PB6PD0(G=]]4AZHML)%`C;"1`">H#A"20````B=&+5"0L!9EY@EH!P8M$
M)"C!X`6)1"0@BT0D*(ML)"`/K-`;B=J)1"0P"VPD,`'IB?V)WP^L[P+!XAZ)
M3"10B4PD((G5"?V);"0PQT0D-`````"+;"0HBU0D0(MT)#C'1"0\`````/?5
M(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"28````B>F)\`69>8):`<&+1"0@B<N)
MQHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P<=$)"P`````"?X!\\'A'C'_
M#ZS0`HG-BU0D,(E<)&`)Q8M$)$");"0XBVPD(/?5(>J+;"10(VPD.`GJ`X0D
MH````(G1BU0D)`69>8):`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D0`ML)$"+
M1"0@`>F)3"10B4PD*(G!P>$>#ZS0`HG-B=H)Q??2B6PD0"-4)#B+;"1@(VPD
M0(M$)#"+="0XQT0D)`````#'1"1$`````,=$)#0`````">H#A"2H````B=&+
M5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B=J)1"0P"VPD,`'I
MB?V)WP^L[P+!XAZ)3"0@B4PD8(G5BU0D0`G]B6PD,(ML)"CWU2'JBVPD4"-L
M)#")Z(G5BU0D)`G%`[0DL````(GIB?`%F7F"6@'!BT0D((G+B<:)QXM$)"C!
MY@6)="0XBW0D.`^LUQN)P0G^`?/!X1XQ_XE<)%"+5"0LB<W'1"0L`````,=$
M)#P`````QT0D1``````/K-`"BU0D,`G%BT0D0(EL)#B+;"0@]]4AZHML)&`C
M;"0X">H#A"2X````B=&+5"0D!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)
M1"1`"VPD0(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<V)V@G%]](C5"0XB6PD
M0(ML)%`C;"1`BT0D,`GJ`X0DP````(G1BU0D+`69>8):`<&+1"0HP>`%B40D
M((M$)"@/K-`;B=J)1"0PBVPD(`ML)#"+="0XQT0D)`````#'1"0T`````,=$
M)#P``````>F)_8G?#ZSO`L'B'HE,)"")3"10B=6+5"1`"?V);"0PBVPD*/?5
M(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3(````B>F)\`69>8):`<&+1"0@B<N)
MQHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P0G^`?/!X1XQ_P^LT`*)S8M4
M)#")7"1@"<6+1"1`B6PD.(ML)"#WU2'JBVPD4"-L)#@)Z@.$)-````")T069
M>8):`<&)V,'@!8E$)"B)V`^L^!N)1"1`BVPD*`ML)$"+1"0@BU0D),=$)"P`
M````QT0D1`````#'1"0D`````,=$)#0`````BW0D.`'IB4PD*(E,)%")P<'A
M'@^LT`*)S8G:"<7WTB-4)#B);"1`BVPD8"-L)$"+1"0P">H#A"38````B=&+
M5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*(ML)"`/K-`;B=J)1"0P"VPD,`'I
MB?V)WP^L[P+!XAZ)3"1@B4PD((G5BU0D0`G]B6PD,(ML)"CWU2'JBVPD4"-L
M)#")Z(G5"<4#M"3@````BU0D)(GIQT0D/`````#'1"1$`````(GP!9EY@EH!
MP8M$)"")RXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!QT0D+``````)
M_@'SP>$>,?\/K-`"B<V+5"0PB5PD4`G%BT0D0(EL)#B+;"0@]]4AZHML)&`C
M;"0X">H#A"3H````B=&+5"0D!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)
M1"1`"VPD0(M$)"`!Z8E,)&")3"0HB<'!X1X/K-`"B<V)V@G%]](C5"0XB6PD
M0(ML)%`C;"1`BT0D,(MT)#C'1"0D`````,=$)#0`````QT0D/``````)Z@.$
M)/````")T8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)VHE$
M)#`+;"0P`>F)_8G?#ZSO`L'B'HE,)"")3"10B=6+5"1`"?V);"0PBVPD*/?5
M(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3X````B>F)\`69>8):`<&+1"0@B<N)
MQHG'BT0D*,'F!8ET)#B+="0X#ZS7&XM4)"R)P0G^`?/!X1XQ_P^LT`*)S8E<
M)&`)Q8EL)#B+;"0@BU0D,(M$)$#'1"0L`````/?5(>J+;"10(VPD.`GJ`X0D
M``$``(G1BU0D),=$)"0`````!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)
M1"1`"VPD0(M$)"`!Z8E,)"B)3"10B<'!X1X/K-`"B<V)V@G%]](C5"0XB6PD
M((ML)&`C;"0@BT0D,`GJ`X0D"`$``(G1BU0D+`69>8):`<&+1"0HP>`%B40D
M,(M$)"B+;"0P#ZS0&XG:B40D0`ML)$`!Z8G]B=\/K.\"P>(>B4PD8(E,)##'
M1"0T`````(ML)"B)TXM4)"`)^XMT)#B)7"1HB5PD0/?5QT0D1`````#'1"0D
M`````"'JBVPD4"'=B>B)U8M4)#0)Q0.T)!`!``")Z8GP!9EY@EH!P8M$)#")
MRXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!"?X!\\'A'C'_#ZS0`HG-
MBTPD((G>"<4#C"08`0``B5PD4(M<)&B);"0XBU0D-(G(!:'KV6XQZXML)&`Q
MW8GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D*`ML)"B+1"0P`>F)3"1@B4PD
M((G!P>$>#ZS0`HG+BU0D0`G#`Y0D(`$``(ML)%")7"1`QT0D+`````")T(M4
M)"0%H>O9;C-<)#@QW8GSB>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)
M1"0P"VPD,`'IP>(>#ZS[`HG5BY0D*`$``(E,)"@)W8E,)%"+7"1`BTPD.(EL
M)#B!PJ'KV6Z)T(M4)"@!R#'KBVPD8(M,)"@QW8M<)"R)[@'&P>(%BT0D((E4
M)#"+;"0P#ZS9&XM4)"2)\PG-B<$!Z\'A'C'_#ZS0`HG-BXPD,`$``(E<)&`)
MQ8M$)$")WHEL)#"+;"0X@<&AZ]EN`<@S;"0PBU0D+#-L)%#'1"0D`````,=$
M)"P`````B>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"1`"VPD0(M$)"@!Z8E,
M)"")3"10B<'!X1X/K-`"B<N+C"0X`0``BU0D)`G#BT0D.(G=B5PD.(M<)#"!
MP:'KV6X!R#'KBVPD8#'=BYPD0`$``(GI`<&+1"0@P>`%B40D*(M$)""+;"0H
M#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"0HB4PD8`GU@<.AZ]EN
MB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI`<&+1"0HBU0D+(G&B<>+1"0@P>8%
MB70D,(MT)#`/K-<;BU0D),=$)"0`````"?X!\3'_B<Z)3"10B<'!X1X/K-`"
MB<V+C"1(`0``BU0D+`G%BT0D.(EL)#"+;"1`@<&AZ]EN`<@S;"0P,VPD8(GI
M`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D.`ML)#B+1"0H`>F)3"0@B4PD8(G!
MP>$>#ZS0`HG+BXPD4`$``(M4)"0)PXM$)$")W8E<)#B+7"0P@<&AZ]EN`<@Q
MZXML)%`QW8GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XGRB40D0`ML)$"+
MG"18`0``BT0D,,=$)"P``````>G!XAX/K/X"B=6)3"10B4PD*`GU@<.AZ]EN
MBU0D+(GOBVPD.`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D*(G+B<:)QXM$)"#!
MY@6)="0PBW0D,`^LUQN+5"0DB<''1"0D``````G^`?/!X1XQ_P^LT`*)S8N,
M)&`!``"+5"0L"<6+1"0XB=Z);"0PBVPD0('!H>O9;HE<)&`!R#-L)#`S;"10
MB>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"0X"VPD.(M$)"@!Z8E,)%")3"0@
MB<'!X1X/K-`"B<N+C"1H`0``"<.+1"1`BU0D)(E<)#B)W8M<)#"!P:'KV6['
M1"0L``````'(,>N+;"1@,=V+G"1P`0``B>D!P8M$)"#!X`6)1"0HBT0D((ML
M)"@/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)&")3"0H"?6!PZ'K
MV6Z+5"0LB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI`<&+1"0HB<N)QHG'BT0D
M(,'F!8ET)#"+="0P#ZS7&XM4)"2)P0G^`?/!X1XQ_P^LT`*)S8N,)'@!``")
M7"10"<6+1"0XB=Z);"0PBVPD0('!H>O9;@'(,VPD,#-L)&")Z0'!B=C!X`6)
M1"0@B=B+;"0@#ZSX&XM4)"S'1"0D`````(E$)#@+;"0XBT0D*,=$)"P`````
M`>F)3"0@B4PD8(G!P>$>#ZS0`HG+BY0D@`$```G#BT0D0(G=B5PD.(M<)#"!
MPJ'KV6X!T(M4)"0QZXML)%`QW8N<)(@!``")Z0'!BT0D(,'@!8E$)"B+1"0@
MBVPD*`^LT!N)\HE$)$`+;"1`BT0D,`'IP>(>#ZS^`HG5B4PD*(E,)%`)]8'#
MH>O9;HM4)"R)[XML)#@!V(E\)$`Q_8GNBVPD8#'UB>D!P8M$)"B)QHG'P>8%
MB70D,(MT)#`/K-<;"?X!\3'_B4PD8(M$)"")SHM4)"3'1"0D`````(G!P>$>
M#ZS0`HG-BXPDD`$``(M4)"P)Q8M$)#C'1"0L`````(EL)#"+;"1`@<&AZ]EN
M`<@S;"0P,VPD4(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D.`ML)#B+1"0H
M`>F)3"0@B4PD4(G!P>$>#ZS0`HG+BXPDF`$``(M4)"0)PXM$)$")W8E<)#B+
M7"0P@<&AZ]EN`<@QZXML)&`QW8GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0
M&XGRB40D0`ML)$`!Z<'B'@^L_@*)U8E,)&")3"0H"?6+G"2@`0``BT0D,(GO
MBVPD.(M4)"R)?"1`QT0D-`````"!PZ'KV6X!V#']B>Z+;"10,?6)Z8ML)&`!
MP8M$)"B)RXG&B<>+1"0@P>8%B70D,(MT)#`/K-<;BU0D)(G!QT0D)``````)
M_@'SP>$>#ZS0`HG.BY0DJ`$``(M,)$`)QHM$)#B)7"0PB?>)7"10@<*AZ]EN
M`=`Q\8M4)#0QS8GI`<&+1"0PP>`%B40D((M$)#"+;"0@#ZS0&XM4)"R)1"0X
M"VPD.(M$)"@!Z8E,)&")3"0@B<'!X1X/K-`"B<Z+E"2P`0``B?D)QHM$)$")
M?"1HBVPD4(M\)""!PJ'KV6Z)="0XBUPD.`'0,?&+5"0T,<W'1"0L`````,=$
M)#0`````B>F+;"0D`<&)^,'@!8E$)"B)^`^LZ!N+;"0H"<6+1"0P`>F)3"10
MB4PD*(G'B<&+1"1@#ZS7`L'A'HG:B<T)_8G?BUPD+`GO(>J);"1`(?B+?"0D
MB<$)T8M4)"B)SHN,)+@!``"!P=R\&X^)R(M,)&@!R(M,)"@!QL'B!8M$)%")
M5"0PBVPD,`^LV1N)\XMT)"`)S0'KB?&)7"0PB5PD8`^L_@+!X1Z+7"1`B<^+
M3"0X"?>)^HE\)%`)VB'0B?HAVHG%"=6+E"3``0``B>Z!PMR\&X^)T(M4)#`!
MR`'&P>(%B50D((M,)#"+7"0TBVPD((M\)"R+1"1@QT0D)`````#'1"0L````
M``^LV1N)\XMT)"@)S0'KB?&)7"0@B5PD:`^L_@*+?"10P>$>B<N+3"1`"?.)
M^HE<)#@)VB'0B?HAVHG%BUPD)`G5BY0DR`$``(GN@<+<O!N/B="+5"0@`<B+
M3"0@`<:+1"1HP>(%B?>+="0PB50D*(ML)"@/K-D;BUPD.(N4)-`!```)S8GQ
M`>_!X1Z)?"0HB7PD8(G-BWPD-(G9#ZS^`@GU">DAZXEL)$`AR(G!"=F!PMR\
M&X^+7"0LB<Z+3"10B="+5"0H`<B+3"0H`<;!X@6)5"0PBVPD,`^LV1N)\XMT
M)""+?"0D"<V+1"1@QT0D-``````!Z\=$)"0`````B?&)7"1HB5PD,`^L_@+!
MX1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?J+?"0L(=J)Q8M<)#0)U8N4)-@!
M``")[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D:,'B!8E4)""+;"0@#ZS9&XGS
MBW0D*`G-`>N)\8E<)"")7"1@#ZS^`HM\)%#!X1Z)RXM,)$`)\XGZB5PD.`G:
M(=")^B':B<6+7"0D"=6+E"3@`0``B>Z!PMR\&X^)T(M4)"`!R(M,)"`!QL'B
M!8GWB50D*(ML)"@/K-D;"<T![XE\)&B)?"0HBW0D,(M\)#2+7"0XBT0D8(N4
M).@!``#'1"0L`````(GQQT0D-``````/K/X"P>$>BWPD),=$)"0`````B<V)
MV0GU">DAZXEL)$`AR(G!"=F!PMR\&X^+7"0LB<Z+3"10B="+5"0H`<B+3"0H
M`<;!X@6+1"1HB50D,(ML)#`/K-D;B?.+="0@"<T!ZXGQB5PD,(E<)&`/K/X"
MP>$>BUPD0(G/BTPD.`GWB?J)?"10"=HAT(GZ(=J)Q8M<)#0)U8N4)/`!``")
M[H'"W+P;CXG0BU0D,`'(BTPD,`'&P>(%B50D((ML)"`/K-D;B?.+="0H"<T!
MZXE<)&B)7"0@B?&+?"0LP>$>BT0D8(G+BTPD0,=$)"P`````#ZS^`HM\)%`)
M\XE<)#B)^@G:(=")^B':B<6+7"0D"=6+E"3X`0``B>Z!PMR\&X^)T(M4)"`!
MR(M,)"`!QHM$)&C!X@6)]XMT)#")5"0HBVPD*`^LV1N+7"0XBY0D``(```G-
MB?$![\'A'HE\)"B)?"1@B<V+?"0TB=G'1"0T``````^L_@*+?"0D"?4)Z2'K
MB6PD0"'(B<$)V8'"W+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,)"@!QL'B!8E4
M)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)&B)7"0P#ZS^`L'A'HM<)$"+1"1@
MB<^+3"0XQT0D)``````)]XGZB7PD4`G:(=")^HM\)"PAVHG%BUPD-`G5BY0D
M"`(``,=$)"P`````B>Z!PMR\&X^)T(M4)#`!R(M,)#`!QHM$)&C!X@6)5"0@
MBVPD(`^LV1N)\XMT)"@)S0'KB?&)7"0@B5PD8`^L_@*+?"10P>$>B<N+3"1`
M"?.)^HE<)#@)VB'0B?HAVHG%BUPD)`G5BY0D$`(``(GN@<+<O!N/B="+5"0@
M`<B+3"0@`<:+1"1@P>(%B?>+="0PB50D*(ML)"@/K-D;BUPD.`G-B?$![\'A
M'HE\)&B)?"0HB<V+?"0TB=D/K/X""?4)Z2'KB6PD0"'(BY0D&`(``(M\)"2)
MP<=$)#0`````QT0D)``````)V8M<)"R)SHM,)%"!PMR\&X^)T(M4)"@!R(M,
M)"@!QL'B!8M$)&B)5"0PBVPD,`^LV1N)\XMT)"`)S0'KB?&)7"0PB5PD8`^L
M_@+!X1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?J+?"0L(=J)Q8M<)#0)U8N4
M)"`"``")[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D8,'B!8E4)""+;"0@#ZS9
M&XGSBW0D*`G-`>N)\8E<)&B)7"0@#ZS^`HM\)%#!X1Z)RXM,)$`)\XGZB5PD
M.`G:(=")^B':B<4)U8N4)"@"``")[H'"W+P;CXG0BU0D((M<)"0!R(M,)"#'
M1"0L``````'&BT0D:,'B!8GWBW0D,(E4)"B+;"0H#ZS9&XM<)#B+E"0P`@``
M"<V)\0'OP>$>B7PD*(E\)&")S8M\)#2)V<=$)#0`````#ZS^`HM\)"0)]0GI
M(>N);"1`(<B)P0G9@<+<O!N/BUPD+(G.BTPD4(G0BU0D*`'(BTPD*`'&P>(%
MBT0D8(E4)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)#")7"1H#ZS^`L'A'HM<
M)$")SXM,)#@)]XGZB7PD4`G:(=")^B':B<4)U8N4)#@"``")[H'"W+P;CXG0
MBU0D,`'(`<;!X@6)5"0@BTPD,(M<)#2+;"0@BWPD+(M$)&C'1"0D`````,=$
M)"P`````#ZS9&XGSBW0D*`G-`>N)\8E<)"")7"1@#ZS^`HM\)%#!X1Z)RXM,
M)$`)\XGZB5PD.`G:(=")^B':B<6+7"0D"=6+E"1``@``B>Z!PMR\&X^)T(M4
M)"`!R(M,)"`!QHM$)&#!X@6)]XMT)#")5"0HBVPD*`^LV1N+7"0XBY0D2`(`
M``G-B?$![\'A'HE\)"B)?"1HB<V+?"0TB=D/K/X""?4)Z2'KB6PD0"'(B<$)
MV8'"W+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,)"@!QL'B!8E4)#"+;"0P#ZS9
M&XGSBW0D((M\)"0)S8M$)&C'1"0T``````'KQT0D)`````")\8E<)#")7"1@
M#ZS^`L'A'HM<)$")SXN,)%0"```)]XGZB7PD4`G:(=")^C'_(=J)Q0G5BY0D
M4`(``(GN@<+<O!N/@]$`B=`QVXG*BTPD.`'(BTPD,!':`<:+7"0T$=>+5"0P
M#ZS9&\'B!8GSB?Z)5"0@BVPD(#'2BWPD+`G-`>N+;"10$=:+E"18`@``B5PD
M((ET)&R+="0HB5PD:(M<)"2)\0^L_@+!X1Z)\(G.BTPD0`G&@<+6P6+*B="+
M5"0@B70D.`'(,?6)Z8ML)&`QS8M,)"")[@'&P>(%B50D*(ML)"@/K-D;BWPD
M,(GSBY0D8`(```G-QT0D+``````!ZXML)#3'1"0T`````(GYB5PD8(E<)"C!
MX1Z+7"1H#ZSO`HG-BTPD4`G]@<+6P6+*BWPD)(G0BU0D*(EL)$`!R(M,)#@Q
MZ3'+BTPD*(G>BUPD+`'&P>(%BT0D.(E4)#"+;"0P#ZS9&XGSBW0D((M4)#0)
MS0'KBVPD8(GQB5PD,(E<)%#!X1Z+7"1`#ZS^`HG/BXPD:`(```GWB7PD.('!
MUL%BR@'(,?LQW8GI`<&+1"0PB<N)Q@^LT!O!Y@6)1"0@BVPD(`GU`>N)7"1@
MB5PD(,=$)"0`````BW0D*(M\)"R+;"0XBT0D0(M4)"2)\<=$)"P`````#ZS^
M`L'A'@GQB<Z+C"1P`@``B70D0('!UL%BR@'(,?6)[HML)%`Q]8GI`<&+1"0@
MB<?!YP6)?"0HB<>+="0H#ZS7&XM$)#"+5"0T"?X!\3'_B<Z)3"10B<'!X1X/
MK-`"B<V+E"1X`@``"<6+1"0XB6PD,(ML)$"!PM;!8LH!T#-L)#"+5"0D,VPD
M8(GI`<&)\,'@!8E$)"B)\(ML)"@/K/@;B40D.`ML)#B+1"0@`>F)3"1@B4PD
M*(G!P>$>#ZS0`HG+BXPD@`(```G#BT0D0(G=B5PD.(M<)#"!P=;!8LJ+5"0L
MQT0D)``````!R#'KBVPD4#'=BYPDB`(``(GI`<&+1"0HP>`%B40D((M$)"B+
M;"0@#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"10B4PD(`GU@</6
MP6+*BU0D)(GOBVPD.`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D((G+B<:)QXM$
M)"C!Y@6)="0PBW0D,`^LUQN+5"0LB<$)_@'SP>$>,?\/K-`"B<V+C"20`@``
MB5PD8`G%BT0D.(G>B6PD,(ML)$"!P=;!8LH!R#-L)#`S;"10B>D!P8G8P>`%
MB40D*(G8#ZSX&XE$)#B+;"0H"VPD.(M$)""+5"0DQT0D+`````#'1"0D````
M``'IB4PD4(E,)"B)P<'A'@^LT`*)RXN,))@"``"+5"0L"<.+1"1`B=V)7"0X
MBUPD,('!UL%BR@'(,>N+;"1@,=V+G"2@`@``B>D!P8M$)"C!X`6)1"0@BT0D
M*(ML)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)"")3"1@"?6!
MP];!8LJ+5"0DB>^+;"0X`=B)?"1`,?V)[HML)%`Q]8GI`<&+1"0@B<N)QHG'
MP>8%B70D,(MT)#`/K-<;"?X!\S'_B5PD4(M$)"B)WHM4)"S'1"0L`````(G!
MP>$>#ZS0`HG-BXPDJ`(``(M4)"0)Q8M$)#C'1"0D`````(EL)#"+;"1`@<'6
MP6+*`<@S;"0P,VPD8(GI`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D.`ML)#B+
M1"0@`>F)3"0HB4PD8(G!P>$>#ZS0`HG+BY0DL`(```G#BT0D0(G=B5PD.(M<
M)#"!PM;!8LH!T(M4)"PQZXML)%`QW8GI`<&+1"0HP>`%B40D((M$)"B+;"0@
M#ZS0&XGRB40D0`ML)$`!Z<'B'@^L_@*)U8E,)%")3"0@"?6+G"2X`@``BT0D
M,(GOBVPD.(M4)"2)?"1`@</6P6+*`=@Q_8GNBVPD8#'UB>D!P8M$)"")RXG&
MB<>+1"0HP>8%B70D,(MT)#`/K-<;BU0D+(G!QT0D+``````)_@'SP>$>,?\/
MK-`"B<V+C"3``@``BU0D)`G%BT0D.(E<)&");"0PBVPD0(G>@<'6P6+*`<@S
M;"0P,VPD4(GI`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D.`ML)#B+1"0@`>F)
M3"10B4PD*(G!P>$>#ZS0`HG+BY0DR`(```G#BT0D0(G=B5PD.(M<)#"!PM;!
M8LH!T#'KBVPD8#'=B>D!P8M$)"B+5"0LBYPDT`(``,=$)"0`````P>`%B40D
M((M$)"B+;"0@#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"1@BU0D
M)`GU@</6P6+*B4PD((GOBVPD.`'8B7PD0#']B=>)[HML)%`Q]8GI`<&+1"0@
MB<L/I,<%B<;!Y@6)?"0TB<>)="0PBT0D*(MT)#`/K-<;BU0D+(G!"?X!\\'A
M'C'_#ZS0`HG-BXPDV`(``(G>"<6)7"10BT0D.(N<)-P"``");"0P@<'6P6+*
MBVPD0(/3`#'2`<@1VC-L)#`QVS-L)&")Z0'!B?`1T\'@!3'2B40D*(GP#ZSX
M&XE$)#B+;"0H"VPD.(M$)"#'1"0L``````'I$=.+5"0DB4PD*(E,)&")P8E<
M)&3!X1['1"0D``````^LT`*)RXN4).`"```)PXM$)$")W8E<)#B+7"0P@<+6
MP6+*`="+5"0L,>N+;"10,=V+G"3H`@``B>D!P8M$)"C!X`6)1"0@BT0D*(ML
M)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)""+5"0D"?6!P];!
M8LJ)3"1`B>^+;"0X`=B)?"0P,?V)UXGNBVPD8#'UB>D!P8M$)"`/I,<%B<;!
MY@6)?"14B<>)="10BW0D4`^LUQN+5"0L"?Z)\`'(,?^)QHM$)"B)P<'A'@^L
MT`*)S8M4)"0)Q8M$)"");"10B=.)P0^DRQ[!X1Z)3"0@B=&)P@^LR@+!Z0*+
M1"0XB5PD)(E,)"R+C"3P`@``BUPD,(E4)"B)^H'!UL%BR@'(,>N+;"1`,=V)
MZ0'!B?#!X`6)1"0XB?"+;"0X#ZSX&P^D\@6)1"1`"VPD0(E4)#R)^L'J&XE4
M)$2+5"1,B>B+;"0@`<B)P8M$)!@#3"00QT($`````,="#``````!\`ML)"B)
M0@B)"HGH`P0DB4(0BT0D4`-$)`C'0A0`````QT(<`````,=")`````")0AB+
M1"0P`T0D6(E"((N$)/P"``!E,P44````=0N!Q`P#``!;7E]=P^C((```D(VT
M)@````!55U93Z"?9__^!PZ./``"#[!R%P`^$JP```(N+,`$``(L)A<F)3"0(
M#X27````#[8(A,ET:X#Y/71FB<:#Q@$/M@Z$R70%@/D]=?$IQHM,)`B+*87M
M=#:)5"0,B40D!(G/C;0F`````(/L!%;_="0,5>BJU?__@\00A<!U!X!\-0`]
M="2#QP2++X7M==N#Q!R)Z%M>7UW#B?:-O"<`````,?;KJ8UT)@")^BM4)`B+
M1"0,C6PU`<'Z`HD0@\0<B>A;7E]=PS'MZ\2-M"8`````5U:)QE/H@MG__X'"
MTHX``(/L$(NZ,`$``(U<)`AEH10```")1"0,,<")VHGPZ/[^__^%P'0[C78`
MC;PG`````(M4)`B+!XT$D(M0!(72B1!TUXVV`````(/`!(M0!(72B1!U](G:
MB?#HP_[__X7`=<^+1"0,93,%%````'4'@\006UY?P^AF'P``C;8`````55>)
MQ593B=;HP]?__X'#/XX``(/L.&6A%````(E$)"@QP#'`@#H]#Y3``<96Z"[3
M__^#Q!")!"2)Z(U4)!CH7?[__X7`#X0-`0``@^P,B<=0Z`K3__^#Q!`Y!"0/
MAMX```"+1"08C0R%`````(N#,`$``(E$)`0/MD4`A,`/A)P!```\/0^$E`$`
M`(GHZP:0@/H]=`J#P`$/MA"$TG7Q*>B+5"0$@^P,BSH!SXM,)`R-1`@"4.A&
MTO__@\00A<")!P^$:P$``(M4)`2-30&+`HM4)!B+%)`/MD4`/#V(`G0CA,!U
M#^L=B?:-O"<`````/#UT$(/!`0^V0?^#P@&$P(@"=>S&`CTQP(VT)@`````/
MM@P&B$P"`8/``83)=?$QP(M<)!QE,QT4````#X4*`0``@\0L6UY?7<.-M@``
M``"#Q@$/MD;_@\<!A,"(1_]U[^O,D(UT)@"+@S`!``"+$(E$)`2+.H7_#X2X
M````,<#K"(VV`````(GXC7@!BPRZA<EU](T$A0P```"+BW01``"%R70[@^P(
M4%+H4='__XM,)!2#Q!"%P(D!#X2"````C0R]`````(E$)`B+1"0(QT2X!```
M``")?"08Z:?^__^)5"0(@^P,QX-T$0```0```%#H&='__X/$$(7`=$2-#+T`
M````@^P$48M4)!")3"044HE$)!10Z+3/__^+3"04BT0D&(/$$(D!BTPD#.N<
M,<#I>_[__[@(````,?_I6?___[C_____Z>7^___H'QT``.L-D)"0D)"0D)"0
MD)"0D%575E.)QNAUU?__@</QBP``@>R,````9:$4````B40D?#'`A?9T!8`^
M`'4DBT0D?&4S!10````/A40!``"!Q(P```!;7E]=PY"-M"8`````@^P,5NAW
MTO__@\00A<")QW3*C8-$D?__B40D"(U$)!R)1"0,C70F`(/L#%?HS]'__X/$
M$(7`B<4/A,H````/ME43N"X```")P2G1=1L/ME44A=)TTRG0#X2;````]]B%
MP'3%ZP>-=@"%R72\@^P,5NA+T/__C543B40D%(D4)(E4)!#H.-#__XM,)!2-
M1`$"B00DZ,C/__^)Q5A:BU0D"%)6_W0D&&K_:@%5Z.#1__^#Q!S_="0056H#
MZ''1__^#Q!"#^/]T$(M$)"PE`/```#T`0```=%&#[`Q5Z-#.__^#Q!"#[`Q5
MZ$3.__^#Q!#I-/___XUT)@`/MD45Z5[___^-M"8`````@^P,5^A?T?__B30D
MZ$?.__^#Q!#IN_[__XVT)@````")Z.B!_O__Z[+HBAL``(UV`(V\)P````!7
M5HG'4^CFT___@<-BB@``@^P,B[,(`0``_S;HX-#__X/$#`4\`0``4%=J`^C?
MT/__@\00A<!T"%LQP%Y?PV:0@^P,_S;HMM#__XN`3`$``(/$$"4`\```/0!`
M``!T'X/L#/\VZ)?0__^+@$P!``"#Q!`E`/```#T`H```=;J#[`AJ`E?HY\__
M_X/$$(7`#Y3`6P^VP%Y?PY"-M"8`````55>)QU93Z$73__^!P\&)``"![#`0
M``!EH10```")A"0@$```,<")5"00:/\/``"-@TJ1__^-="0D5E#HL,W__X/$
M$(7`?F&-:/^`?"P<`'1/B<6#[`15:B]6Z!'/__^#Q!"%P'1"BX,(`0``@^P,
M_S#HZL___U565U#H@<___X/$((N$)!P0``!E,P44````=3F!Q"P0``!;7E]=
MPXUV`(7M=:^-="8`BX,(`0``@^P,_S#HJ,___X/$#/]T)!!74.@ZS?__@\00
MZ[?H$!H``%/H>M+__X'#]H@``(/L%(N#"`$``/\PZ'3/__^-DT"3__]2C9-9
MD?___[,$`0``4E#H*L[__X/$*%O#D(UT)@!64^@YTO__@<.UB```@^P0B[,(
M`0``_S;H,\___XD$).B;____6/\VZ"//__]:C9/PDO__66H`4E*-DV2,__]2
MC9-UD?__4E#H8\[__X/$)%M>PXVV`````(V\)P````!55U93Z-?1__^!PU.(
M``"![!P@``!EH10```")A"0,(```,<#HM\S__XV359'__X/L"%)0C8.*D?__
M4&@!$```:@&-="0F5NCTSO__@\0@A<!X;8/L!&@`$```C;PD$Q```%=6Z!?,
M__^#Q!"%P(G%>$Z-0`&#[`Q0Z)+,__^#Q!"%P(G&=!*#[`155U#H7LO__\8$
M+@"#Q!"+C"0,(```93,-%````(GP=1F!Q!P@``!;7E]=PXUV`(V\)P`````Q
M]NO5Z*<8``"-M"8`````Z2O___^-="8`C;PG`````%575E/H]]#__X'#<X<`
M`('L+!```(N$)$`0``"-5"08B[0D1!```(D$)(G'9:$4````B80D'!```#'`
MC8.8D?__Z(KW__^#[`B)Q6HO5^@=S/__@\00A<!T,8L\)(V#H9'__XGZZ,;X
M__^)^(N4)!P0``!E,Q44````#X68`0``@<0L$```6UY?7<.#[`S_="0,Z/G+
M__]:68G'C8.ND?__B40D#%!6Z.3,__^)QHU'`8/$$(E$)`B+@P@!``")1"0,
MC;8`````A?9TCH`^``^$VP```(7M=!6#[`A65>C=R?__@\00A<`/A*,```"#
M[`Q6Z)G+__^#Q!"`?`;_+W45C;0F`````(/H`8!\!O\OQ@0&`'3R`T0D"#W_
M#P``#X\U____C8.PD?__@^P$_W0D!%"-@ZN2__]64&@`$```:@&-="0X5N@4
MS?__@\04BWPD&/\WZ+;,__^#Q`P%/`$``%!6:@/HE<S__X/$$(7`=1^#[`S_
M-^B4S/__BX!,`0``@\00)0#P```]`(```'17@^P(_W0D#&H`Z/'+__^#Q!")
MQND?____C;0F`````(7M="2-@Y:1__^Y`@```(GNB<?SIG3*B<:X`0```.E#
M____D(UT)@"-LY:1__^X`0```.DN____@^P(:@%6Z(W+__^#Q!"%P'67C8.A
MD?__B?+H*??__X/L#%;H\,K__X/$$.E4_O__Z',6``"-=@"+1"0$#[8(A,ET
M%8U0`6:0@/DO#[8*#T3"@\(!A,EU\//#C;0F`````(V\)P````!64^BISO__
M@<,EA0``@^P4BW0D((7V=%`/MA:$TG1)B%0D#X/L#%;H%,K__XU$!O^#Q!`/
MME0D#SG&<@OK'F:0@^@!.<9T&8`X+W3TZP=FD(`X+W1`@^@!.<9R]#G&=36`
M^B]U<XUV`(/L#&H"Z&[)__^#Q!"%P'17NBX```!FB1"#Q!1;7L.)]HV\)P``
M``"`."]U!X/H`3G&<O0I\(U0`H'Z`!```'<G@\`!:``0``!05HVS=`$``%;H
M0<K__X/$$(GP@\046U[#C;8`````@\04,<!;7L.-@["1__^#[`Q0Z,G)__^#
MQ!#KE8UT)@!75E/HN,W__X'#-(0``(/L,&6A%````(E$)"PQP(N#')/__XUT
M)`2)1"0*BX,@D___B40D#HN#))/__XE$)!*+@RB3__^)1"06BX,LD___B40D
M&HN#,)/__XE$)!Z+@S23__^)1"0BBX,XD___B40D)@^W@SR3__]FB40D*HV#
MLI'__^C8]/__C8.[D?__Z,WT__^-@\.1___HPO3__XV#S)'__^BW]/__C8/3
MD?__Z*ST__^-@^.1___HH?3__XV#F)'__^B6]/__C8/OD?__Z(OT__^-@_F1
M___H@/3__XV#`Y+__^AU]/__C8.AD?__Z&KT__^-@PV2__^)\NB-\___A<!T
M#8G"C8/YD?__Z-ST__^-@QZ2__^)\NAO\___A<!T#8G"C8,PDO__Z+[T__^-
M@SN2__^)\NA1\___A<!T-8G"C8.8D?__Z*#T__^-DV>2__^-@].1___HC_3_
M_XM$)"QE,P44````=5:#Q#!;7E_#C78`C8-+DO__B?+H"_/__X7`=!>)PHV#
M[Y'__^A:]/__Z[B0C;0F`````(UT)!N-NUR2__^Y"@```/.F=9V-5"0EC8/O
MD?__Z"[T___KC.B'$P``C;0F`````%/HZLO__X'#9H(``(/L&&6A%````(E$
M)`PQP(N#/`$``(/X_W0:BTPD#&4S#10```!U08/$&%O#D(VT)@````"-5"0(
MC8/OD?__Z''R__^%P'0=#[80@/HP#Y7`A-(/E<(AT`^VP(F#/`$``.NX9I`Q
MP.OOZ`<3``"-M"8`````4^AJR___@</F@0``@^P(Z,S%__^#[`Q0Z#/%__^#
MQ!"%P'0,BP"#Q`A;PY"-="8`,<#K\HVV`````(V_`````%575E/H)\O__X'#
MHX$``(/L'&6A%````(E$)`PQP(U4)`B-@VF2__^+?"0PZ,_Q__^%P'0S@#@`
MB<9T+(/L"%=0Z)K$__^#Q!"%P'0SBT0D#&4S!10```!U>8/$'%M>7UW#C;8`
M````C8-IDO__B?KHZ_+__^O6B?:-O"<`````@^P,5^@WQO__B<6)-"3H+<;_
M_XU$!0*)!"3HP<7__XG%C8.ND?__@\0,5E"-@ZN2__]74&K_:@%5Z-+'__^-
M@VF2__^#Q"")ZNB2\O__Z7K____HZ!$``)"-M"8`````55=64^@B$0``@<7#
M@```@>P\@0``BX0D4($``(U4)#R-G7F2___'1"1(`````,=$)&P`````B5PD
M3,=$)%0`````B40D'(E4)!1EH10```")A"0L@0``,<"-A862__^)1"1`C866
MD?__B40D1(V%,)+__XE$)`R)1"18C84IDO__B40D7(V%BI+__XE$)&"-A4:2
M__^)1"1DC862DO__B40D:(V%EI+__XE$)%"-A9B1___H:/#__X7`=`F`.``/
MA7L$``#H%O[__X7`B<8/A),$``"#[`R)ZU;H`<7__XU$``&)!"3HE<3__XE$
M)""#Q!"`/@!T-HV%GY+__XM\)!")!"2-="8`#[8&@^P,B>N#Q@%0_W0D$&K_
M:@%7@\<"Z(O&__^#Q""`/@!UVXU<)%B+1"0,BWPD%.L.D(UT)@"#PP2+`X7`
M="^)^NC0[___A<")QG3J@#@`=.7H`/7__X7`=-R#[`R)ZU;HX<3__X/$$(7`
MB<=U0HM<)$`Q]NL+@\8!BURT0(7;="V`.P!T*(G8Z,GT__^%P'3E@^P,4XGK
MZ*K$__^#Q!"%P'33B<?K"8VT)@`````Q_X/L#(GK5^@;Q/__@\00BTPD$(L9
M@\$$C9/__O[^]],AVH'B@("`@'3IB=/!ZQ#WPH"````/1-.-60(/1,N)TP#3
MB>N#V0,K3"00@^P,C;0!!`0``%;H;,/__XE$)!R)P8V%I)+___]T)"!0C86P
MD?__B40D*%"-A:F2__]7B<]0:O]J`5'H;,7__X/$*&C``0``5^CNP___@\00
M@_C_#X22````B[T(`0``@^P,B>O_-^CPQ/__@\0,!3P!``!0_W0D%&H#Z.S$
M__^)1"0P@\00A<`/A*4```"#[`R)Z_]T)!B+1"0L_S"-A8B3__]0BX4``0``
M:@'_,.AXQ/__@\0@QT0D&`````"+C"0L@0``93,-%````(M$)!@/A4D*``"!
MQ#R!``!;7E]=PXUV`(V\)P````#H:\/__XL`@_@1#X1>____@^P(4/]T)!B+
M1"0L_S"-A4R3__]0BX4``0``:@'_,.@,Q/__@\0@QT0D&`````#KDHVT)@``
M``"#[`S_-^@>Q/__BX!,`0``@\00)0#P```]`$````^%./___X/L#/\WZ/O#
M__^+@%0!``")1"00Z$S!__^#Q!`Y!"0/A1/___^#[`S_-^C6P___BX!,`0``
M@\00)?\!```]P`$```^%\/[__X/L#(GK5NC2P?__BU0D)(E$)"B-A722___H
M7^W__X/$$(7`#X0$`@``@^P,B>M0Z'G"__]:65"+1"0H_S#H:_7__XE$)!"#
MQ!"%P`^$W`$``(/L#(GKBWPD#%?HW<'__X/$$(/X`WXMC70'_(G[C;VRDO__
MN04```#SIG48@_@$#X2F!P``@'P#^R\/A)L'``"-="8`Z"/Z__^%P'4?@^P(
MB>MJ`/]T)`SHK\'__XE$)"R#Q!"%P`^%?@$``(V59Y+__XVU\)+__XV%[Y'_
M_XGKC;W9DO__Z`'N___HS,#__U90C87+DO___W0D&/]T)!A0:O]J`?]T)#3H
M#L/__X/$((DT)(E\)!2+="0@BWPD&.M`C78`C;PG`````.B;P?__@S@1=42)
MZX/&`>A\P/__@^P,_W0D#%90_W0D*/]T)"C_="0T:O]J`5?HO<+__X/$,(/L
M"(GK:,`!``!7Z#K!__^#Q!"#^/]TLH/L#(GK_W0D&.@TO___BWPD*(V%F)'_
M_XGZZ%/M__^)/"3HZ_G__X/$$.F&_?__C78`@^P,B>M0B40D$.C1^?__BT0D
M$(D$).CUP/__B40D*(/$$.E<_?__OP$```")V(MT)!3K#XUT)@"+1+Q,@\<!
MA<!T*8GRZ);K__^%P'3J@#@`=.6#[`R)ZU#HLL#__X/$$(7`=-.)QNDH^___
M@^P,B>N-M7Z2__]J#>C"O___B40D((/$$.DM^___C;8`````BT0D'(L`B00D
MZ1;^__]J`FK_:NZ+?"0H5^A2O___@\0,:@:-A"0T`0``B40D'%!7Z!N^__^#
MQ!"`O"0L`0```'4.@+PD+0$``$,/A&\&``!J`&H`B>MJ`/]T)"CH#[___\>$
M)(`````!(T5GQX0DA`````````#'A"2(````B:O-[\>$)(P`````````QX0D
MD````/[<NIC'A"24`````````,>$))@```!V5#(0QX0DG`````````#'A"2@
M````\.'2P\>$)*0`````````QX0DJ`````````#'A"2L`````````,>$)+``
M````````QX0DM`````````#'A"3X`````````(/$$(U$)'")+"2)1"0LC80D
MJ````(E$)""0@^P$:`"```#_="0<_W0D*(M<)!#H%[W__X/$$(7`B<8/C@L"
M``"+C"28````BYPDG````(GPB?7!X`.)]\']'P'(@_L`#X?-`0``.<$/A\4!
M``"+C"2@````BYPDI````(F$))@```")^(GJ#ZSH'<'J'<>$))P`````````
M`<B)A"2@````BX0DZ````!':B90DI````(7`#X1I`0``OT`````IQSG^#T[^
M`T0D((/L!%?_="0<4(M<)!#HK[S__XN$)/@````!^(F$)/@```"#Q!"#^$`/
MA2/___^+1"0L*?X#?"04Z*3#__^-="8`@_X_#X[H````C4;`BVPD+(G^B40D
M*,'H!HU8`8E$)"3!XP8!^XUV`(L&@\9`B80DJ````(M&Q(F$)*P```"+1LB)
MA"2P````BT;,B80DM````(M&T(F$)+@```"+1M2)A"2\````BT;8B80DP```
M`(M&W(F$),0```"+1N")A"3(````BT;DB80DS````(M&Z(F$)-````"+1NR)
MA"34````BT;PB80DV````(M&](F$)-P```"+1OB)A"3@````BT;\B80DY```
M`(GHZ,_"__\Y\P^%3____XM,)"B)R(/@P(U\!T"+1"0DP>`&*<&)SFI$5E?_
M="0LBUPD$.B^O/__B;0D^````(/$$.G__?__C;0F`````(M\)!3IW_[__XVT
M)@````"+C"2@````BYPDI````(/!`8/3`.DP_O__BRPD@^P,_W0D*(GKZ$Z^
M__^+A"2P````BYPDJ````(NT)*P```"+E"2T````B40D$(G8#ZSP`XE4)!2#
MX#^-4`'&A`2X````@(/$$(/Z.`^/I`(``+@X````*=`#5"0@@_@$#X/)`@``
MA<!T"Z@"Q@(`#X5_`P``BU0D!(L$)(B<).<````/K-`8BU0D!(B$).````"+
M!"0/K-`0BU0D!(B$).$```"+!"0/K-`(B(0DX@````^V!"2(A"3C````B=@/
MK/`8B(0DY````(G8#ZSP$(B$).4```")V`^L\`B(A"3F````BT0D+.AOP?__
MBW0D<(M\)'2)\0^L^1B(C"3O````#[;!B?$/K/D0B(PD\````(GQ#ZSY"(M\
M)'R(C"3Q````B?&+="1XB(PD\@```(GQ#ZSY&(B,)/,```")\0^L^1"(C"3T
M````B?$/K/D(B[PDA````(B,)/4```")\8NT)(````"(C"3V````B?$/K/D8
MB(PD]P```(GQ#ZSY$(B,)/@```")\0^L^0B+O"2,````B(PD^0```(GQB[0D
MB````(B,)/H```")\0^L^1B(C"3[````B?$/K/D0B(PD_````(GQ#ZSY"(N\
M))0```"(C"3]````B?&+M"20````B(PD_@```(GQ#ZSY&(B,)/\```")\0^L
M^1"(C"0``0``B?$/K/D(C;PD*P$``(B,)`$!``")\8VT)/````"(C"0"`0``
MC8PD`P$``(E,)!R)RHV-GY+__XD,)(E\)!2)]XG6Z0<```"0#[8'@\<!@^P,
MB>M0_W0D$&K_:@%6@\8"Z".\__^#Q"`Y="04==J-A?"2___&A"0K`0```(GK
M4(V%O)+___]T)"#_="08_W0D&%!J_VH!_W0D-.CIN___@\0@Z3_Y__^+1"0<
MBU`$A=(/A%KX__^#[`R)ZU*)5"0DZ/.Y__^#Q!"#^`,/AC_X__^+5"04C;VW
MDO__N04```"-=`+\\Z8/110DB10DZ1[X__^+3"0@N$`````!T2G0B<)T#3'`
MQ@0!`(/``3G0<O6+1"0LZ#^___^+?"0@N0X````QP/.KZ4;]__^-2@3'`@``
M``#'1`+\`````(/A_"G*`<*#XOR#^@0/@B+]__^#XOPQP,<$`0````"#P`0Y
MT'+RZ0K]__^`O"0N`0``00^%@_G__X"\)"\!``!##X5U^?__@+PD,`$``$@/
MA6?Y__^`O"0Q`0``10^%6?G__VH":O]JQHMT)"A6Z&FX__^#Q`QJ*8M\)!Q7
M5N@YM___C87PDO__4(V%O)+__U?_="0H_W0D*%!J_VH!_W0D1.BENO__@\0P
MZ?OW__^0C70F`#')9HE,`O[I=?S__^BW!```C;0F`````%575E/H%[W__X'#
MDW,``(/L.(NK"`$``&6A%````(E$)"@QP/]U`.@$NO__7_]U`(G&Z/FY__\/
MMD!HB$9IC40D*(E$)!R)PHV#TY'__^B=X___@\00A<!T"8`X,0^$?0(``.CX
M[O__@^P,_W4`Z+VY__^-D^J2__]J"VH!4E#HW+?__X/$((7`#X2R````BT`,
M@[M\$0```8M`&(E$)`0/CIL````Q_[X!````ZRV0BT(,@^P(4(N#>!$``/\T
ML.@;MO__@\00A<!U9(N#?!$``(/&`8/'`3GP?EJ#[`S_=0#H2;G__VH`5_]T
M)!Q0Z,RX__^#Q""%P'0UBQ"+0@@E``0@`#T`!```=*2)5"0(@^P,_W4`Z!6Y
M__]J`FH`BU0D(%)0Z+:V__^#Q"#KA)"+@WP1``"-4/\Y^@^$7P$``(/L#/]U
M`.CDN/__C9/ODO__:@-J`5)0Z`.W__^#Q""%P(G&=#.+0`R#[`R+./]U`.BZ
MN/__C9/QDO__@\0,4E=0Z$FV__^+1@R#Q!"+,/9&"D`/A;`!``"#[`S_=0#H
MC+C__XV3]I+__VH#:@%24.BKMO__@\0@A<")QG0WBU0D#(V#H9'__^@CXO__
MA<")QP^$20$``(M&#(/L#(LP_W4`Z$FX__^#Q`Q75E#HWK7__X/$$(/L#/]U
M`.@PN/__C9/XDO__@\0,:@%24.C.MO__B<98_W4`Z!.X__^-DPV3__^#Q`Q2
M5E#HHK7__UK_=0#H^;?__XM4)!S&0&D`C8.8D?__Z*;A__^#Q!"%P(G&B8.`
M$0``#X23````@^P(:,`!``!6Z*6V__^-4`&#Q!"#^@%V"8/X$0^%ZP```(M$
M)!QE,P44````#X75````@\0L6UY?7<.0C;0F`````(/X`0^.F/[__XM\)`2^
M`0```(VV`````(/L#/]U`(/&`>AJM___6EE74.AQM/__@\00.;-\$0``?][I
M8O[__Y"`>`$`#X1^_?__Z73]__^0@^P,_[-X$0``Z-+O__^#Q!"%P(G&B8.`
M$0``#X5,____C8/<D___@^P,4.C0M?__BX-X$0``@^P,BSB+1@R+,/]U`.CX
MMO__B?J)\.B/YO__@\00Z:S^__^#[`S_=0#HW+;__UE?5E#H`[;__X/$$.DT
M_O__Z$8!``!0BX-X$0``5O\PC8,`E/__4.APM?__5U93BW0D$.B4N?__@<,0
M<```@^P,5NC5ZO__#[8(@\00A,ET2(U0`8G'C;8`````@/DO#[8*#T3Z@\(!
MA,EU\.AK[?__A?9T((7`=!R`/@!T%XV#I)+__X/L"%!7Z.ZR__^#Q!`Y^'0(
M6UY?PXG'Z\];B?!>7^FEX___BRPDPY!3Z!JY__^!PY9O``"#[`B-@S@!``"%
MP'0?BP!0_W0D'/]T)!S_="0<Z-.S__^#Q!A;PXVV`````#'`Z]]FD&:055=6
M4^C7N/__@<-3;P``@^P,BVPD((VS\/[__^@[LO__C8/L_O__*<;!_@*%]G0E
M,?^-M@````"#[`3_="0L_W0D+%7_E+OL_O__@\<!@\00.?YUXX/$#%M>7UW#
MC78`\\-FD&:09I!FD&:09I!FD%/H:KC__X'#YFX``(/L".B\LO__4X/L".A3
MN/__@<//;@``@\0(6\,#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/
M5``O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$52
M3#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!
M4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`
M3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``
M55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C
M:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8
M`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`S-P`M90`M+0````!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I+F,`
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*
M;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@
M)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE
M('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A
M9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S
M970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I
M9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@
M,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@
M/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D
M9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET
M=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@
M)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S
M=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*
M)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F
M*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@`!&P,[\````!T```"L<O__#`$``'QV__\P`0``C';__[`-```\>O__1`$`
M`-R?__^(`0``K*#__^P!```\H?__)`(``(RC__^D`@``'*7__UP#``"\I?__
MS`,``(RF__]H!```S*;__Y@$```LI___Y`0``/RG__]X!0``#*C__XP%```L
MJO__B`8``%RJ__^<!@``3*O__Q`'```<K?__2`<``)RM__]L!P``W*W__Y@'
M``"\KO__!`@``.R[___L"P``;+___V`-``#GO___^`T``.R___\,#@``+,#_
M_T`.``",P/__C`X``)S`__^@#@``%``````````!>E(``7P(`1L,!`2(`0``
M(````!P```"8<?__T`,````."$8.#$H/"W0$>``_&CLJ,B0B$````$````!$
M=?__$`````````!`````5````/!X__^8)0```$$."(4"00X,AP-$#A"&!$$.
M%(,%1@Z@!@.!)0H.%$'##A!!Q@X,0<<."$'%#@1!"P```&````"8````3)[_
M_\D`````00X(A0)!#@R'`T$.$(8$00X4@P5.#C`"60XT00XX1`X\00Y`2`XP
M5PH.%$/##A!!Q@X,0<<."$'%#@1*"UX*#A1#PPX00<8.#$''#@A!Q0X$00LT
M````_````+B>__^*`````$$."(<"00X,A@-##A"#!$X.(`)N"@X00<,.#$'&
M#@A!QPX$00L``'P````T`0``$)___T$"````00X(A0)!#@R'`T,.$(8$00X4
M@P50#DQ7#E!(#D!9#DQ##E!(#D`"3PY,30Y02`Y``G@*#A1!PPX00<8.#$''
M#@A!Q0X$1PL"6`Y(00Y,00Y03`Y`<0Y,2PY02`Y`3@Y$00Y(20Y,10Y04`Y`
M````M````+0!``#@H/__A@$```!!#@B%`D$.#(<#00X0A@1!#A2#!5,.H`%L
M"@X40<,.$$'&#@Q!QPX(0<4.!$D+0PZL`4$.L`%(#J`!7PZL`4$.L`%(#J`!
M>PZL`4$.L`%K#JP!00ZH`44.K`%!#K`!1`ZT`4(.N`%"#KP!00[``4@.I`%$
M#J@!00ZL`4(.L`%(#J`!6`ZL`4$.L`%(#J`!0PZL`4$.L`%(#J`!7`ZL`4$.
ML`%0#J`!`&P```!L`@``N*'__Y@`````00X(AP)!#@R&`T,.$(,$3@X<2`X@
M2`X41@X800X<0@X@2`X010K##@Q#Q@X(0<<.!$,+0PX<0@X@3@X03PX<0@X@
M3@X03PX80@X<00X@2`X01L,.#$3&#@A!QPX$``"8````W`(``.BA___0````
M`$$."(4"00X,AP-##A"&!$$.%(,%40[$(%@.R"!+#LP@00[0($@.P"!3#L0@
M00[(($(.S"!!#M`@2`[`($T.S"!"#M`@1@[4($$.V"!!#MP@00[@($@.P"!6
M"@X40<,.$$'&#@Q!QPX(0<4.!$0+40[,($(.T"!(#L0@1`[(($$.S"!!#M`@
M2`[`(``L````>`,``!RB__\[`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP
M2`X(0<,.!`!(````J`,``"RB__]3`````$$."(8"00X,@P-.#AQ(#B!.#AQ"
M#B!&#AQ'#AA"#AQ!#B!!#B1'#BA'#BQ!#C!(#@Q!PPX(0<8.!```D````/0#
M``!`HO__R0````!!#@B%`D$.#(<#00X0A@1!#A2#!5$.L$!=#KA`00Z\0$$.
MP$!'#L1`10[(0$(.S$!%#M!`2`ZP0$<.M$!%#KA`2`Z\0$$.P$!(#K!`3`Z\
M0$$.P$!(#K!`20ZT0$$.N$!!#KQ`00[`0$P.L$!8"@X40<,.$$'&#@Q!QPX(
M0<4.!$L+`!````"(!```?*+__P4`````````^````)P$``!XHO__'0(```!!
M#@B%`D$.#(<#00X0A@1!#A2#!5$.P"!T#L@@1`[,($$.T"!(#L`@<`H.%$'#
M#A!!Q@X,0<<."$'%#@1!"T,.S"!$#M`@1@[,($$.R"!-#LP@00[0($T.P"!H
M#L@@00[,($$.T"!(#L`@2P[,($$.T"!(#L`@=`[$($0.R"!!#LP@1P[0($$.
MU"!%#M@@0@[<($4.X"!(#LP@1@[0($@.Q"!&#L@@00[,($(.T"!(#L`@1P[,
M($(.T"!.#L`@3P[(($0.S"!"#M`@2`[`(`))#L@@0@[,($$.T"!(#L`@5`[,
M($$.T"!(#L`@$````)@%``"<H___(@````````!P````K`4``+BC___L````
M`$$."(8"00X,@P-.#B!6#BQ!#C!,#B!X#BQ"#C!(#B!/"@X,0<,."$'&#@1*
M"V$.)$$.*$$.+$<.,$@.($4*#@Q!PPX(0<8.!$<+0PH.#$/##@A!Q@X$00M)
M#BQ!#C!(#B```#0````@!@``-*3__\D!````00X(AP)!#@R&`T$.$(,$3@Y`
M`V`!"@X00<,.#$'&#@A!QPX$1`L`(````%@&``#,I?__>0````!!#@B#`DX.
M(&<*#@A!PPX$20L`*````'P&```HIO__-`````!!#@B#`DX.$$@.'$$.($@.
M$$D*#@A!PPX$1@MH````J`8``#RF___8`````$$."(4"00X,AP-!#A"&!$$.
M%(,%3@XP;0XX00X\00Y`2`XP5`H.%$'##A!!Q@X,0<<."$'%#@1'"UL./$$.
M0&8.-$$..$$./$<.0$$.1$(.2$(.3$$.4$X.,`#D`P``%`<``+"F__\I#0``
M`$$."(4"00X,AP-!#A"&!$$.%(,%40[0@@("P@[<@@)##N""`E@.T(("7`[<
M@@)&#N""`D0.Y(("0@[H@@)"#NR"`D$.\(("2P[0@@)_#MR"`D,.X(("2`[0
M@@)L#MR"`D$.X(("2@[0@@)4#MR"`D,.X(("2`[0@@)_#MR"`D@.X(("50[D
M@@)!#NB"`DL.[(("1P[P@@)##O2"`D(.^(("0@[\@@)!#H"#`D@.V(("10[<
M@@)!#N""`D@.T(("4@[<@@)$#N""`D@.U(("1@[8@@)$#MR"`D(.X(("3`[0
M@@)+#MR"`D8.X(("1@[D@@)'#NB"`D@.[(("0@[P@@)(#M""`F8*#A1!PPX0
M0<8.#$''#@A!Q0X$2PM3#MB"`D$.W(("1`[@@@)&#N2"`D<.Z(("2`[L@@)"
M#O""`D@.T(("5`[<@@)"#N""`DX.T(("4P[<@@)"#N""`E<.T(("3`[<@@)"
M#N""`DX.T(("4P[<@@)##N""`EL.T(("2P[<@@)##N""`D8.W(("00[8@@)!
M#MR"`D8.X(("3`[0@@)+#MR"`D<.X(("2`[0@@)^#MB"`D0.W(("1`[@@@),
M#M""`FT.U(("00[8@@)*#MR"`D0.X(("00[D@@)"#NB"`D(.[(("1`[P@@)(
M#M""`G(.W(("1`[@@@)!#N2"`D$.Z(("1`[L@@)$#O""`D0.](("0@[X@@)"
M#OR"`D$.@(,"2`[0@@)##MB"`D<.W(("00[@@@)(#M""`D@.W(("1@[@@@)A
M#M""`DL.W(("0P[@@@)<#M""`G0.W(("0P[@@@)(#M""`DX.W(("2@[@@@),
M#M""`EL.U(("0@[8@@)"#MR"`D4.X(("2`[4@@)"#MB"`DP.W(("00[@@@)(
M#M""`EH.U(("0@[8@@)$#MR"`D0.X(("`JT.T(("6@[4@@)%#MB"`D0.W(("
M1`[@@@),#M""`@*6#M2"`D$.V(("1`[<@@)!#N""`EP.T(("`P\!#M2"`D$.
MV(("00[<@@)$#N""`E,.T((">P[<@@)$#N""`@)"#M""`@,,`@[<@@)##N""
M`D0.Y(("0@[H@@)"#NR"`D$.\(("2P[0@@)7#M2"`DH.V(("1`[<@@)$#N""
M`D$.Y(("0@[H@@)"#NR"`D0.\(("2`[0@@)7#MR"`D,.X(("3`[0@@("V0[4
M@@)"#MB"`D(.W(("10[@@@)(#M2"`D(.V(("10[<@@)!#N""`DP.Y(("1P[H
M@@)$#NR"`D0.\(("00[T@@)"#OB"`D(._(("1`Z`@P)(#M""`@``<`$``/P*
M``#XK___@`,```!!#@B%`D$.#(<#00X0A@1!#A2#!4X.3%4.4$8.3$,.4&8.
M0%4.3$,.4$T.5$(.6$$.7$$.8$@.0&\.2$$.3$D.4$@.0%<.3$,.4$<.5$$.
M6$0.7$$.8$@.0%P.3$,.4$<.5$(.6$4.7$$.8$@.0%<.3$,.4$T.5$(.6$$.
M7$$.8$@.0$P.3$4.4$X.1$$.2$$.3$$.4$L.0$\.3$,.4$T.5$(.6$$.7$$.
M8$@.0&4.3$4.4$@.1$$.2$$.3$$.4$@.0$,.3$,.4$X.1$(.2$$.3$$.4$@.
M3$,.4$X.1$$.2$$.3$$.4$8.3$,.4%L.0%,.2$4.3$$.4$L.0&(*#A1!PPX0
M0<8.#$''#@A!Q0X$20M;#DQ##E!)#DQ!#DA!#DQ!#E!(#D!A"@Y,1@Y02`Y`
M60Y,00Y010M)#DQ*#E!1#D!(#DQ##E!&#DQ!#DA!#DQ!#E!(#D!+#D1'#DA"
M#DQ'#E``3````'`,```$LO__>P````!!#@B'`D$.#(8#00X0@P12#AQ!#B!+
M#A!Z#AA!#AQ!#B!(#A!%"L,.#$'&#@A!QPX$00M%PPX,0\8."$''#@1$````
MP`P``-1H__]``@```$0,`0!'$`4"=0!&#P-U<`80!P)U?!`&`G5X$`,"=70#
M>P$*P0P!`$'#0<9!QT'%0PP$!$$+```0````"`T``.>Q__\$`````````#``
M```<#0``V+'__SP`````00X(@P).#A!-#A1$#AA$#AQ$#B!(#@A!PPX$1PX0
M@P(```!(````4`T``.2Q__]=`````$$."(4"00X,AP-!#A"&!$$.%(,%3@X@
M:0XD1`XH1`XL00XP30X@1PX40<,.$$'&#@Q!QPX(0<4.!```$````)P-``#X
ML?__`@`````````8````L`T``/2Q__\4`````$$."(,"3@X0````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$`9``#P&`````````$````!`````0```-\!```!````
M+@(```P```#,$0``#0```/1?```9````N,T``!L````$````&@```+S-```<
M````!````/7^_V^L`0``!0```/P(```&````C`(```H```#O!```"P```!``
M```5``````````,```#,S@```@```.`!```4````$0```!<```#L#P``$0``
M`%P/```2````D````!,````(````'@````@```#[__]O`0``"/[__V^\#@``
M____;P(```#P__]O[`T``/K__V\%````````````````````````````````
M`````````````````````````,3-``````````````82```6$@``)A(``#82
M``!&$@``5A(``&82``!V$@``AA(``)82``"F$@``MA(``,82``#6$@``YA(`
M`/82```&$P``%A,``"83```V$P``1A,``%83``!F$P``=A,``(83``"6$P``
MIA,``+83``#&$P``UA,``.83``#V$P``!A0``!84```F%```-A0``$84``!6
M%```9A0``'84``"&%```EA0``*84``"V%```QA0``-84``#F%```]A0```85
M```6%0``)A4``#85``!&%0``5A4``&85``!V%0``AA4``)85``"F%0``MA4`
M`````````````````````````````````````````````````-`5````````
M``````````````````````30``#_____$&,``$=#0SH@*%5B=6YT=2`V+C0N
M,"TR=6)U;G1U,2D@-BXT+C`@,C`Q-S`W,C0`1T-#.B`H56)U;G1U(#8N-"XP
M+3%U8G5N='4R*2`V+C0N,"`R,#$W,#<P-```+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````
M``````````````````````````````````````````````````````L````!
M`````@```%0!``!4`0``$P```````````````0`````````3````!P````(`
M``!H`0``:`$``"````````````````0`````````(0````<````"````B`$`
M`(@!```D```````````````$`````````#0```#V__]O`@```*P!``"L`0``
MX`````4`````````!`````0````^````"P````(```",`@``C`(``'`&```&
M`````0````0````0````1@````,````"````_`@``/P(``#O!```````````
M```!`````````$X```#___]O`@```.P-``#L#0``S@````4``````````@``
M``(```!;````_O__;P(```"\#@``O`X``*`````&`````@````0`````````
M:@````D````"````7`\``%P/``"0````!0`````````$````"````',````)
M````0@```.P/``#L#P``X`$```4````7````!`````@```!\`````0````8`
M``#,$0``S!$``",```````````````0`````````=P````$````&````\!$`
M`/`1``#0`P`````````````0````!````((````!````!@```,`5``#`%0``
M$```````````````"`````@```"+`````0````8```#0%0``T!4``"1*````
M`````````!``````````D0````$````&````]%\``/1?```4````````````
M```$`````````)<````!`````@````A@```(8```/#\`````````````!```
M``````"?`````0````(```!$GP``1)\``/0```````````````0`````````
MK0````$````"````.*```#B@``#,#0`````````````$`````````+<````.
M`````P```+C-``"XO0``!```````````````!`````0```##````#P````,`
M``"\S0``O+T```0```````````````0````$````SP````$````#````P,T`
M`,"]```$```````````````$`````````-0````&`````P```,3-``#$O0``
M"`$```8`````````!`````@```"&`````0````,```#,S@``S+X``#0!````
M``````````0````$````W0````$````#`````-````#````0````````````
M```$`````````.,````(`````P```"#0```0P```-!``````````````(```
M``````#H`````0```#``````````$,```%@```````````````$````!````
H`0````,``````````````&C```#Q```````````````!````````````
